@@ -49,20 +49,17 @@ class KubeDescheduler(NamespacedResource):
         self.operator_log_level = operator_log_level
 
     def to_dict(self):
-        res = super().to_dict()
-        if self.yaml_file:
-            return res
-
-        res.update(
-            {
-                "spec": {
-                    "deschedulingIntervalSeconds": self.descheduling_interval,
-                    "logLevel": self.log_level,
-                    "managementState": self.management_state,
-                    "mode": self.mode,
-                    "operatorLogLevel": self.operator_log_level,
-                    "profiles": self.profiles,
+        super().to_dict()
+        if not self.yaml_file:
+            self.res.update(
+                {
+                    "spec": {
+                        "deschedulingIntervalSeconds": self.descheduling_interval,
+                        "logLevel": self.log_level,
+                        "managementState": self.management_state,
+                        "mode": self.mode,
+                        "operatorLogLevel": self.operator_log_level,
+                        "profiles": self.profiles,
+                    }
                 }
-            }
-        )
-        return res
+            )
